Module blocking

Module blocking 

Blocking version of the sp1-sdk ProverClient.

Re-exports

pub use crate::utils;

Modules

prelude
A prelude for the blocking API, including all the types and traits that are commonly used.

Structs

CpuProver
A prover that uses the CPU to execute and prove programs.
CpuProverBuilder
A builder for the CpuProver.
LightProver
A lightweight blocking prover that only executes and verifies but does not generate proofs.
MockProver
A mock prover that can be used for testing.
NetworkProver
A blocking implementation of the network prover that can generate proofs on a remote RPC server.
NetworkProverBuilder
A builder for the blocking NetworkProver.
ProverClient
An entrypoint for interacting with the prover for the SP1 RISC-V zkVM.
SP1PublicValues
Public values for the prover.
SP1Stdin
Standard input for the prover.

Enums

Elf
A type that represents an ELF binary, always cheap to clone.
EnvProver
A prover that can execute programs and generate proofs with a different implementation based on the value of the SP1_PROVER environment variable.
EnvProvingKey
SP1ProofMode

Traits

ProveRequest
A unified collection of methods for all prover types.
Prover
The entire user-facing functionality of a prover.