pub enum EnvProver {
Mock(MockProver),
Light(LightProver),
Cpu(CpuProver),
Network(Box<NetworkProver>),
}Expand description
A prover that can execute programs and generate proofs with a different implementation based on
the value of the SP1_PROVER environment variable.
Variants
Mock(MockProver)
A mock prover that does not prove anything.
Light(LightProver)
A light prover that only executes and verifies but does not generate proofs.
Cpu(CpuProver)
A CPU prover.
Network(Box<NetworkProver>)
A network prover.
Implementations
Sourceimpl EnvProver
impl EnvProver
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new EnvProver from the environment.
This method will read from the SP1_PROVER environment variable to determine which prover
to use. If the variable is not set, it will default to the CPU prover.
If the prover is a network prover, the NETWORK_PRIVATE_KEY variable must be set.
Sourcepub fn new_with_machine(machine: Machine<SP1Field, RiscvAir<SP1Field>>) -> Self
pub fn new_with_machine(machine: Machine<SP1Field, RiscvAir<SP1Field>>) -> Self
Same as Self::new but with a custom machine.
Sourcepub fn with_opts(self, opts: SP1CoreOpts) -> Self
pub fn with_opts(self, opts: SP1CoreOpts) -> Self
Updates the core options for this prover.
This method allows you to configure the prover after creation. It recreates the prover with the new options based on the current environment settings.
Example
use sp1_core_executor::SP1CoreOpts;
use sp1_sdk::blocking::ProverClient;
let mut client = ProverClient::from_env();
let opts = SP1CoreOpts { shard_size: 500_000, ..Default::default() };
client = client.with_opts(opts);Sourcepub fn from_env_with_opts(core_opts: Option<SP1CoreOpts>) -> Self
pub fn from_env_with_opts(core_opts: Option<SP1CoreOpts>) -> Self
Creates an EnvProver from the environment with optional custom SP1CoreOpts.
This method will read from the SP1_PROVER environment variable to determine which prover
to use. If the variable is not set, it will default to the CPU prover.
If the prover is a network prover, the NETWORK_PRIVATE_KEY variable must be set.
Sourcepub fn from_env_with_opts_and_machine(
core_opts: Option<SP1CoreOpts>,
machine: Machine<SP1Field, RiscvAir<SP1Field>>,
) -> Self
pub fn from_env_with_opts_and_machine( core_opts: Option<SP1CoreOpts>, machine: Machine<SP1Field, RiscvAir<SP1Field>>, ) -> Self
Same as Self::from_env_with_opts but with a custom machine.