NetworkProver

Struct NetworkProver 

pub struct NetworkProver { /* private fields */ }
A blocking implementation of the network prover that can generate proofs on a remote RPC server.

Implementations

Source

impl NetworkProver

pub fn network_mode(&self) -> NetworkMode

Gets the network mode of this prover.

pub fn default_fulfillment_strategy(&self) -> FulfillmentStrategy

Gets the default fulfillment strategy for this prover’s network mode.

pub fn get_balance(&self) -> Result<U256>

Get the credit balance of your account on the prover network.

Example
use sp1_sdk::blocking::{Prover, ProverClient, SP1Stdin};

let client = ProverClient::builder().network().build();
let balance = client.get_balance().unwrap();
pub fn register_program(&self, vk: &SP1VerifyingKey, elf: &[u8]) -> Result<B256>

Registers a program if it is not already registered.

Details
  • vk: The verifying key to use for the program.
  • elf: The elf to use for the program.
pub fn get_proof_request_params( &self, mode: SP1ProofMode, ) -> Result<GetProofRequestParamsResponse>

Gets the proof request parameters from the network.

Details
  • mode: The proof mode to get the parameters for.
pub fn get_proof_status( &self, request_id: B256, ) -> Result<(GetProofRequestStatusResponse, Option<SP1ProofWithPublicValues>)>

Gets the status of a proof request.

Details
  • request_id: The request ID to get the status of.
pub fn get_proof_request( &self, request_id: B256, ) -> Result<Option<ProofRequest>>

Gets the proof request details, if available.

Details
  • request_id: The request ID to get the details of.
pub fn process_proof_status( &self, request_id: B256, remaining_timeout: Option<Duration>, ) -> Result<(Option<SP1ProofWithPublicValues>, FulfillmentStatus)>

Gets the status of a proof request with handling for timeouts and unfulfillable requests.

Details
  • request_id: The request ID to get the status of.
  • remaining_timeout: The remaining timeout for the proof request.
pub fn cancel_request(&self, request_id: B256) -> Result<()>

Cancels a proof request by updating the deadline to the current time. Only available in Mainnet mode (auction-based proving).

pub fn wait_proof( &self, request_id: B256, timeout: Option<Duration>, auction_timeout: Option<Duration>, ) -> Result<SP1ProofWithPublicValues>

Waits for a proof to be generated and returns the proof. If a timeout is supplied, the function will return an error if the proof is not generated within the timeout.