Prover

Trait Prover 

pub trait Prover:
    Clone
    + Send
    + Sync {
    type ProvingKey: ProvingKey;
    type Error: Debug + Display;
    type ProveRequest<'a>: ProveRequest<'a, Self>
       where Self: 'a;

    // Required methods
    fn inner(&self) -> &SP1NodeCore;
    fn setup(&self, elf: Elf) -> Result<Self::ProvingKey, Self::Error>;
    fn prove<'a>(
        &'a self,
        pk: &'a Self::ProvingKey,
        stdin: SP1Stdin,
    ) -> Self::ProveRequest<'a>;

    // Provided methods
    fn version(&self) -> &str { ... }
    fn execute(&self, elf: Elf, stdin: SP1Stdin) -> ExecuteRequest<'_, Self> { ... }
    fn verify(
        &self,
        proof: &SP1ProofWithPublicValues,
        vkey: &SP1VerifyingKey,
        status_code: Option<StatusCode>,
    ) -> Result<(), SP1VerificationError> { ... }
}
The entire user-facing functionality of a prover.

Required Associated Types

type ProvingKey: ProvingKey

The proving key used for this prover type.

type Error: Debug + Display

The possible errors that can occur when proving.

type ProveRequest<'a>: ProveRequest<'a, Self> where Self: 'a

The prove request builder.

Required Methods

fn inner(&self) -> &SP1NodeCore

The inner SP1NodeCore struct used by the prover.

fn setup(&self, elf: Elf) -> Result<Self::ProvingKey, Self::Error>

Setup the prover with the given ELF.

fn prove<'a>( &'a self, pk: &'a Self::ProvingKey, stdin: SP1Stdin, ) -> Self::ProveRequest<'a>

Prove the given program on the given input in the given proof mode.

Provided Methods

fn version(&self) -> &str

The version of the current SP1 circuit.

fn execute(&self, elf: Elf, stdin: SP1Stdin) -> ExecuteRequest<'_, Self>

Execute the program on the given input.

fn verify( &self, proof: &SP1ProofWithPublicValues, vkey: &SP1VerifyingKey, status_code: Option<StatusCode>, ) -> Result<(), SP1VerificationError>

Verify the given proof.

If the status code is not set, the verification process will check for success.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl Prover for EnvProver

Source

type Error = Error

Source

type ProvingKey = EnvProvingKey

Source

type ProveRequest<'a> = EnvProveRequest<'a>

Source

impl Prover for CpuProver

Source

type ProvingKey = SP1ProvingKey

Source

type Error = CPUProverError

Source

type ProveRequest<'a> = CpuProveBuilder<'a>

Source

impl Prover for LightProver

Source

type ProvingKey = SP1ProvingKey

Source

type Error = CPUProverError

Source

type ProveRequest<'a> = LightProveRequest<'a>

Source

impl Prover for MockProver

Source

type ProvingKey = SP1ProvingKey

Source

type Error = CPUProverError

Source

type ProveRequest<'a> = MockProveRequest<'a>

Source

impl Prover for NetworkProver

Source

type ProvingKey = SP1ProvingKey

Source

type Error = Error

Source

type ProveRequest<'a> = NetworkProveBuilder<'a>