pub struct NetworkClient { /* private fields */ }Expand description
A client for interacting with the network.
Implementations
Sourceimpl NetworkClient
impl NetworkClient
Sourcepub fn new(
signer: NetworkSigner,
rpc_url: impl Into<String>,
network_mode: NetworkMode,
) -> Self
pub fn new( signer: NetworkSigner, rpc_url: impl Into<String>, network_mode: NetworkMode, ) -> Self
Creates a new NetworkClient with the given signer, rpc url, and network mode.
Sourcepub fn get_explorer_url(&self) -> &'static str
pub fn get_explorer_url(&self) -> &'static str
Get the explorer URL for the current network mode.
Sourcepub async fn get_balance(&self) -> Result<U256>
pub async fn get_balance(&self) -> Result<U256>
Sourcepub fn get_vk_hash(vk: &SP1VerifyingKey) -> Result<B256>
pub fn get_vk_hash(vk: &SP1VerifyingKey) -> Result<B256>
Get the verifying key hash from a verifying key.
Details
The verifying key hash is used to identify a program.
Sourcepub async fn register_program(
&self,
vk: &SP1VerifyingKey,
elf: &[u8],
) -> Result<B256>
pub async fn register_program( &self, vk: &SP1VerifyingKey, elf: &[u8], ) -> Result<B256>
Registers a program with the network if it is not already registered.
Sourcepub async fn get_program(
&self,
vk_hash: B256,
) -> Result<Option<GetProgramResponse>>
pub async fn get_program( &self, vk_hash: B256, ) -> Result<Option<GetProgramResponse>>
Sourcepub async fn create_program(
&self,
vk_hash: B256,
vk: &SP1VerifyingKey,
elf: &[u8],
) -> Result<CreateProgramResponse>
pub async fn create_program( &self, vk_hash: B256, vk: &SP1VerifyingKey, elf: &[u8], ) -> Result<CreateProgramResponse>
Creates a new program on the network.
Sourcepub async fn get_proof_request_params(
&self,
mode: ProofMode,
) -> Result<GetProofRequestParamsResponse>
pub async fn get_proof_request_params( &self, mode: ProofMode, ) -> Result<GetProofRequestParamsResponse>
Gets the proof request parameters from the network. This is only available in Mainnet (auction) mode.
Sourcepub async fn get_filtered_proof_requests(
&self,
version: Option<String>,
fulfillment_status: Option<i32>,
execution_status: Option<i32>,
minimum_deadline: Option<u64>,
vk_hash: Option<Vec<u8>>,
requester: Option<Vec<u8>>,
fulfiller: Option<Vec<u8>>,
from: Option<u64>,
to: Option<u64>,
limit: Option<u32>,
page: Option<u32>,
mode: Option<i32>,
not_bid_by: Option<Vec<u8>>,
execute_fail_cause: Option<i32>,
settlement_status: Option<i32>,
error: Option<i32>,
) -> Result<GetFilteredProofRequestsResponse>
pub async fn get_filtered_proof_requests( &self, version: Option<String>, fulfillment_status: Option<i32>, execution_status: Option<i32>, minimum_deadline: Option<u64>, vk_hash: Option<Vec<u8>>, requester: Option<Vec<u8>>, fulfiller: Option<Vec<u8>>, from: Option<u64>, to: Option<u64>, limit: Option<u32>, page: Option<u32>, mode: Option<i32>, not_bid_by: Option<Vec<u8>>, execute_fail_cause: Option<i32>, settlement_status: Option<i32>, error: Option<i32>, ) -> Result<GetFilteredProofRequestsResponse>
Get all the proof requests that meet the filter criteria.
Sourcepub async fn get_proof_request_status<P: DeserializeOwned>(
&self,
request_id: B256,
timeout: Option<Duration>,
) -> Result<(GetProofRequestStatusResponse, Option<P>)>
pub async fn get_proof_request_status<P: DeserializeOwned>( &self, request_id: B256, timeout: Option<Duration>, ) -> Result<(GetProofRequestStatusResponse, Option<P>)>
Sourcepub async fn get_proof_request_details(
&self,
request_id: B256,
timeout: Option<Duration>,
) -> Result<GetProofRequestDetailsResponse>
pub async fn get_proof_request_details( &self, request_id: B256, timeout: Option<Duration>, ) -> Result<GetProofRequestDetailsResponse>
Get the details of a given proof request.
Sourcepub async fn request_proof(
&self,
vk_hash: B256,
stdin: &SP1Stdin,
mode: ProofMode,
version: &str,
strategy: FulfillmentStrategy,
timeout_secs: u64,
cycle_limit: u64,
gas_limit: u64,
min_auction_period: u64,
whitelist: Option<Vec<Address>>,
auctioneer: Address,
executor: Address,
verifier: Address,
treasury: Address,
public_values_hash: Option<Vec<u8>>,
base_fee: u64,
max_price_per_pgu: u64,
domain: Vec<u8>,
private_stdin: bool,
) -> Result<RequestProofResponse>
pub async fn request_proof( &self, vk_hash: B256, stdin: &SP1Stdin, mode: ProofMode, version: &str, strategy: FulfillmentStrategy, timeout_secs: u64, cycle_limit: u64, gas_limit: u64, min_auction_period: u64, whitelist: Option<Vec<Address>>, auctioneer: Address, executor: Address, verifier: Address, treasury: Address, public_values_hash: Option<Vec<u8>>, base_fee: u64, max_price_per_pgu: u64, domain: Vec<u8>, private_stdin: bool, ) -> Result<RequestProofResponse>
Creates a proof request with the given verifying key hash and stdin.
Details
vk_hash: The verifying key hash of the program to prove. Used to identify the program.stdin: The standard input to provide to the program.mode: TheProofModeto use.version: The version of the SP1 circuits to use.strategy: TheFulfillmentStrategyto use.timeout_secs: The timeout for the proof request in seconds.cycle_limit: The cycle limit for the proof request.gas_limit: The gas limit for the proof request.min_auction_period: The minimum auction period for the proof request in seconds.whitelist: The auction whitelist for the proof request.auctioneer: The auctioneer for the proof request.executor: The executor for the proof request.verifier: The verifier for the proof request.treasury: The treasury for the proof request.public_values_hash: The hash of the public values to use for the proof.base_fee: The base fee to use for the proof request.max_price_per_pgu: The maximum price per PGU to use for the proof request.domain: The domain bytes to use for the proof request.
Sourcepub async fn cancel_request(
&self,
request_id: B256,
) -> Result<CancelRequestResponse>
pub async fn cancel_request( &self, request_id: B256, ) -> Result<CancelRequestResponse>
Cancel a proof request. This is only available in Mainnet (auction) mode.