pub enum ClientError {
Http(Error),
Event(EventStreamError<Error>),
Parse(Error),
Decode(FromHexError),
ServerError(String),
NoResponse,
}Expand description
Errors that can occur when interacting with the TEE server.
Variants
Http(Error)
An error occurred while sending the request.
Event(EventStreamError<Error>)
An error occurred while receiving the response.
Parse(Error)
An error occurred while parsing the response.
Decode(FromHexError)
An error occurred while decoding the event.
ServerError(String)
An error occurred while the server returned an error.
NoResponse
No response was received from the server.