pub struct SP1ProofWithPublicValues {
pub proof: SP1Proof,
pub public_values: SP1PublicValues,
pub sp1_version: String,
pub tee_proof: Option<Vec<u8>>,
}Expand description
A proof generated by the SP1 RISC-V zkVM bundled together with the public values and the version.
Fields
proof: SP1ProofThe raw proof generated by the SP1 RISC-V zkVM.
public_values: SP1PublicValuesThe public values generated by the SP1 RISC-V zkVM.
sp1_version: StringThe version of the SP1 RISC-V zkVM (not necessary but useful for detecting version mismatches).
tee_proof: Option<Vec<u8>>The integrity proof generated by the TEE server.
Implementations
Sourceimpl SP1ProofWithPublicValues
impl SP1ProofWithPublicValues
Sourcepub const fn new(
proof: SP1Proof,
public_values: SP1PublicValues,
sp1_version: String,
) -> Self
pub const fn new( proof: SP1Proof, public_values: SP1PublicValues, sp1_version: String, ) -> Self
Creates a new SP1ProofWithPublicValues from the proof, public values, and SP1 version.
If the [tee] feature is enabled, the proof field is set to none.
Sourcepub fn bytes(&self) -> Vec<u8> ⓘ
pub fn bytes(&self) -> Vec<u8> ⓘ
The proof in the byte encoding the onchain verifiers accepts for SP1ProofMode::Groth16
and SP1ProofMode::Plonk proofs.
Details
The bytes consist of the first four bytes of Groth16/Plonk vkey hash followed by the encoded proof, in a form optimized for onchain verification.
Sourcepub fn create_mock_proof(
vk: &SP1VerifyingKey,
public_values: SP1PublicValues,
mode: SP1ProofMode,
sp1_version: &str,
) -> Self
pub fn create_mock_proof( vk: &SP1VerifyingKey, public_values: SP1PublicValues, mode: SP1ProofMode, sp1_version: &str, ) -> Self
Creates a mock proof for the specified proof mode from the public values.
Example
use sp1_sdk::{
Elf, Prover, ProverClient, ProvingKey, SP1ProofMode, SP1ProofWithPublicValues, SP1Stdin,
SP1_CIRCUIT_VERSION,
};
tokio_test::block_on(async {
let elf = Elf::Static(&[1, 2, 3]);
let stdin = SP1Stdin::new();
let client = ProverClient::builder().cpu().build().await;
let pk = client.setup(elf.clone()).await.unwrap();
let (public_values, _) = client.execute(elf, stdin).await.unwrap();
// Create a mock Plonk proof.
let mock_proof = SP1ProofWithPublicValues::create_mock_proof(
&pk.verifying_key(),
public_values,
SP1ProofMode::Plonk,
SP1_CIRCUIT_VERSION,
);
});Trait Implementations
Sourceimpl Clone for SP1ProofWithPublicValues
impl Clone for SP1ProofWithPublicValues
Sourcefn clone(&self) -> SP1ProofWithPublicValues
fn clone(&self) -> SP1ProofWithPublicValues
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for SP1ProofWithPublicValues
impl Debug for SP1ProofWithPublicValues
Sourceimpl<'de> Deserialize<'de> for SP1ProofWithPublicValues
impl<'de> Deserialize<'de> for SP1ProofWithPublicValues
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Sourceimpl From<ProofFromNetwork> for SP1ProofWithPublicValues
impl From<ProofFromNetwork> for SP1ProofWithPublicValues
Sourcefn from(value: ProofFromNetwork) -> Self
fn from(value: ProofFromNetwork) -> Self