Blocking version of the sp1-sdk ProverClient.
Re-exports
pub use crate::utils;
Modules
- prelude
- A prelude for the blocking API, including all the types and traits that are commonly used.
Structs
- CpuProver
- A prover that uses the CPU to execute and prove programs.
- CpuProver
Builder - A builder for the
CpuProver. - Light
Prover - A lightweight blocking prover that only executes and verifies but does not generate proofs.
- Mock
Prover - A mock prover that can be used for testing.
- Network
Prover - A blocking implementation of the network prover that can generate proofs on a remote RPC server.
- Network
Prover Builder - A builder for the blocking
NetworkProver. - Prover
Client - An entrypoint for interacting with the prover for the SP1 RISC-V zkVM.
- SP1Public
Values - Public values for the prover.
- SP1Stdin
- Standard input for the prover.
Enums
- Elf
- A type that represents an ELF binary, always cheap to clone.
- EnvProver
- A prover that can execute programs and generate proofs with a different implementation based on
the value of the
SP1_PROVERenvironment variable. - EnvProving
Key - SP1Proof
Mode
Traits
- Prove
Request - A unified collection of methods for all prover types.
- Prover
- The entire user-facing functionality of a prover.