NetworkProverBuilder

Struct NetworkProverBuilder 

pub struct NetworkProverBuilder { /* private fields */ }
A builder for the blocking NetworkProver.

The builder is used to configure the NetworkProver before it is built.

Implementations

Source

impl NetworkProverBuilder

pub fn new() -> Self

Creates a new NetworkProverBuilder.

pub const fn new_with_machine( machine: Machine<SP1Field, RiscvAir<SP1Field>>, ) -> Self

Creates a new NetworkProverBuilder with a given machine.

pub fn private_key(self, private_key: &str) -> Self

Sets the Secp256k1 private key (same format as the one used by Ethereum).

Details

Sets the private key that will be used sign requests sent to the network. By default, the private key is read from the NETWORK_PRIVATE_KEY environment variable.

Example
use sp1_sdk::blocking::ProverClient;

let prover = ProverClient::builder().network().private_key("...").build();
pub fn rpc_url(self, rpc_url: &str) -> Self

Sets the remote procedure call URL.

Details

The URL determines the network that the client will connect to. By default, the URL is read from the NETWORK_RPC_URL environment variable.

Example
use sp1_sdk::blocking::ProverClient;

let prover = ProverClient::builder().network().rpc_url("...").build();
pub fn private(self) -> Self

Process proofs inside a TEE.

Details

In order to keep the inputs private, it is possible to route the proof requests to a TEE enclave.

Example
use sp1_sdk::blocking::ProverClient;

let prover = ProverClient::builder().network().private().build();
pub fn hosted(self) -> Self

Configures the prover for hosted proving.

Details

Hosted proving runs in NetworkMode::Reserved and makes prove(&pk, stdin) skip local simulation and use the maximum cycle and gas limits by default, with no network-specific toggles required. This matches the behavior expected by self-hosted clusters talking to the network-gateway. The defaults remain overridable per request.

Example
use sp1_sdk::blocking::ProverClient;

let prover = ProverClient::builder().network().hosted().build();
pub fn tee_signers(self, tee_signers: &[Address]) -> Self

Sets the list of TEE signers, used for verifying TEE proofs.

pub fn signer(self, signer: NetworkSigner) -> Self

Sets the network signer to use for signing requests.

Details

This method allows you to provide a custom signer implementation, such as AWS KMS or a local private key signer. If both signer and private_key are provided, the signer takes precedence.

pub fn build(self) -> NetworkProver

Builds a blocking NetworkProver.

Details

This method will build a NetworkProver with the given parameters. If signer is provided, it will be used directly. Otherwise, if private_key is provided, a local signer will be created from it. If neither is provided, the method will look for the NETWORK_PRIVATE_KEY environment variable.

Example
use sp1_sdk::blocking::ProverClient;

let prover = ProverClient::builder().network().private_key("...").build();